==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/sv.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Skicka statistik",
    "An error occurred while sending your report." : "Ett fel inträffade när rapporten sändes.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Applista <em>(för varje app: namn, version, aktiveringsstatus)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databasmiljö <em>(typ, version, databasstorlek)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformation <em>(Aktiverad?, modul i grundinställningar)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antal delningar <em>(per typ och rättighetsinställning)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljö<em>(version, minnesgräns, max. exekveringstid, max. filstorlek)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serverinstansdetaljer <em>(version, använt memcache, status över låsning/förhandsvisning/avatarer)</em>",
    "Help improve Nextcloud" : "Hjälp till att  förbättra Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vill du hjälpa oss förbättra Nextcloud genom att förse oss med anonym data om din installation och användning? Du kan stänga av det när som helst i administratörsinställningarna.",
    "Not now" : "Inte nu",
    "Send usage" : "Skicka statistik",
    "Never" : "Aldrig",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjälpa till att förbättra Nextcloud genom att sända oss viss data om din nuvarande installation och användning.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar din integritet på allvar. Skicka data är inaktiverat som standard och om du ändå vill sätta på det blir det först anonymiserat och du får välja vad som ska delas. När en rapport tas emot kommer den förra tas bort. Ladda upp en ren rapport för att ta bort all data som lagras på servern nu",
    "Send new report now" : "Skicka rapporten nu",
    "Send usage survey monthly" : "Skicka användarstatistik månadsvis",
    "Data to send" : "Data att inkludera",
    "Last report" : "Senaste rapport",
    "Sent on: {on}" : "Sändes: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Antal: filer, användare, lagringar per typ, kommentarer och taggar)</em>",
    "Sent on: %s" : "Sändes: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/sv.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Skicka statistik",
    "Last report sent on: {on}" : "Senaste rapporten sänd den: {on}",
    "An error occurred while sending your report." : "Ett fel inträffade när rapporten sändes.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Applista <em>(för varje app: namn, version, aktiveringsstatus)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Databasmiljö <em>(typ, version, databasstorlek)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Krypteringsinformation <em>(Aktiverad?, modul i grundinställningar)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Antal delningar <em>(per typ och rättighetsinställning)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-miljö<em>(version, minnesgräns, max. exekveringstid, max. filstorlek)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Serverinstansdetaljer <em>(version, använt memcache, status över låsning/förhandsvisning/avatarer)</em>",
    "Help improve Nextcloud" : "Hjälp till att  förbättra Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Vill du hjälpa oss förbättra Nextcloud genom att förse oss med anonym data om din installation och användning? Du kan stänga av det när som helst i administratörsinställningarna.",
    "Not now" : "Inte nu",
    "Send usage" : "Skicka statistik",
    "Never" : "Aldrig",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Skickar anonymiserade data till Nextcloud för att hjälpa oss att förbättra Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Skickar anonymiserade data till Nextcloud för att hjälpa oss att förbättra Nextcloud. Du\n        har alltid full kontroll över innehållet som skickas till Nextcloud och kan inaktivera\n        det igen när som helst.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Du kan hjälpa till att förbättra Nextcloud genom att sända oss viss data om din nuvarande installation och användning.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vi tar din integritet på allvar. Skicka data är inaktiverat som standard och om du ändå vill sätta på det blir det först anonymiserat och du får välja vad som ska delas. När en rapport tas emot kommer den förra tas bort. Ladda upp en ren rapport för att ta bort all data som lagras på servern nu",
    "Send new report now" : "Skicka rapporten nu",
    "Send usage survey monthly" : "Skicka användarstatistik månadsvis",
    "Data to send" : "Data att inkludera",
    "Last report sent on: %s" : "Senaste rapporten skickad den: %s",
    "Last report" : "Senaste rapport",
    "Sent on: {on}" : "Sändes: {on}",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistik <em>(Antal: filer, användare, lagringar per typ, kommentarer och taggar)</em>",
    "Sent on: %s" : "Sändes: %s"
},
"nplurals=2; plural=(n != 1);");
